<?php 
/**
 * Plugin Name: Web Librarian WP Plugin
 * Plugin URI: http://www.deepsoft.com/WebLibrarian
 * Description: A plugin that implements a web-based library catalog and circulation System
 * Version: 2.1
 * Author: Robert Heller
 * Author URI: http://www.deepsoft.com/
 *
 *  Web Librarian WP Plugin
 *  Copyright (C) 2011  Robert Heller D/B/A Deepwoods Software
 *			51 Locke Hill Road
 *			Wendell, MA 01379-9728
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *
 */

define('WEBLIB_FILE', basename(__FILE__));
define('WEBLIB_DIR' , dirname(__FILE__));
define('WEBLIB_INCLUDES', WEBLIB_DIR . '/includes');
define('WEBLIB_CONTEXTUALHELP', WEBLIB_DIR . '/contexual_help');
global $wpmu;
if ($wpmu == 1) {
	define('WEBLIB_BASEURL', get_bloginfo('wpurl') . '/mu-plugins/' .
			basename(WEBLIB_DIR));
} else {
	define('WEBLIB_BASEURL', get_bloginfo('wpurl') . '/wp-content/plugins/' . 
			basename(WEBLIB_DIR));
}
define('WEBLIB_CSSURL', WEBLIB_BASEURL . '/css');
define('WEBLIB_JSURL', WEBLIB_BASEURL . '/js');
define('WEBLIB_IMAGEURL', WEBLIB_BASEURL . '/images');
define('WEBLIB_DOCURL', WEBLIB_BASEURL . '/user_manual');

/* Load Database code */
require_once(WEBLIB_INCLUDES . '/database_code.php');
/* Load Admin Code */
require_once(WEBLIB_INCLUDES . '/admin_page_classes.php');
/* Load Front End code */
require_once(WEBLIB_INCLUDES . '/short_codes.php');
class WebLibrarian {

    private $version = '2.1';
    private $admin_page;
    private $short_code_class;

    /* Constructor: register our activation and deactivation hooks and then
     * add in our actions.
     */
    function __construct() {
	// Add the installation and uninstallation hooks
	register_activation_hook(WEBLIB_DIR . '/' . WEBLIB_FILE, 
				array($this,'install'));
	register_deactivation_hook(WEBLIB_DIR . '/' . WEBLIB_FILE,
				array($this,'deinstall'));
	add_action('wp_head', array($this, 'wp_head'));
	add_action('admin_head', array($this, 'admin_head'));
	add_action('widgets_init', array($this, 'widgets_init'));
	add_action('admin_menu', array($this, 'admin_menu'));
	add_filter('body_class', array($this, 'body_class'));
	add_action('weblib_admin_daily_event',array($this,'every_day'));
	add_option('weblib_aws_public_key','');
	add_option('weblib_aws_private_key','');
	add_option('weblib_aws_regiondom','com');
	add_option('weblib_associate_tag','');

	$this->short_code_class = new WEBLIB_ShortCodes();

	//if (is_admin()) {
	//  wp_enqueue_script('jquery-ui-sortable');
	//}	
    }
    function install() {
	$this->add_roles_and_caps();
	WEBLIB_make_tables();
	wp_schedule_event(mktime(2,0,0), 'daily', 'weblib_admin_daily_event');
    }
    function deinstall() {
	$this->remove_roles_and_caps();
	wp_clear_scheduled_hook('weblib_admin_daily_event');
    }
    function add_roles_and_caps() {
	global $wp_roles;
	$librarian = get_role('librarian');
	if ($librarian == null) {
	    add_role('librarian', 'Librarian', array('read' => true,
						     'edit_users' => true,
						     'manage_patrons' => true,
						     'manage_collection' => true,
						     'manage_circulation' => true));
	} else {
	    $librarian->add_cap('edit_users');
	    $librarian->add_cap('manage_patrons');
	    $librarian->add_cap('manage_collection');
	    $librarian->add_cap('manage_circulation');
	}
	$senioraid = get_role('senioraid');
	if ($senioraid == null) {
	    add_role('senioraid', 'Senior Aid', array('read' => true,
						      'manage_collection' => true,
						      'manage_circulation' => true));
	} else {
	    $senioraid->add_cap('manage_collection');
	    $senioraid->add_cap('manage_circulation');
	}
	$volunteer = get_role('volunteer');
	if ($volunteer == null) {
	    add_role('volunteer', 'Volunteer', array('read' => true,
						     'manage_circulation' => true));
	} else {
	    $volunteer->add_cap('manage_circulation');
	}
    }
    function remove_roles_and_caps() {
	global $wp_roles;
	$librarian = get_role('librarian');
	if ($librarian  != null) {
	    $librarian->remove_cap ( 'manage_patrons' );
	    $librarian->remove_cap ( 'manage_collection' );
	    $librarian->remove_cap ( 'manage_circulation' );
	    $librarian->remove_cap ( 'edit_users' );
	}
	$senioraid = get_role('senioraid');
	if ($senioraid  != null) {
	    $senioraid->remove_cap ( 'manage_collection' );
	    $senioraid->remove_cap ( 'manage_circulation' );
	}
	$volunteer = get_role('volunteer');
	if ($volunteer  != null) {
	    $volunteer->remove_cap ( 'manage_circulation' );
	}
    }
    function wp_head() {
	$path = WEBLIB_CSSURL . '/front.css?version='.$this->version;
	echo '<link rel="stylesheet" type="text/css" href="' . $path . '" />';
	echo "\n";
	$path = WEBLIB_JSURL . '/front.js?version='.$this->version;
	echo '<script type="text/javascript" src="' . $path . '"></script>';
	echo "\n";
	echo '<script> var WEBLIB_BASEURL = "'.WEBLIB_BASEURL.'";</script>';
	echo "\n";
    }
    function admin_head() {
	$path = WEBLIB_CSSURL . '/front.css?version='.$this->version;
	echo '<link rel="stylesheet" type="text/css" href="' . $path . '" />';
	echo "\n";
	$path = WEBLIB_JSURL . '/front.js?version='.$this->version;
	$path = WEBLIB_CSSURL . '/admin.css?version='.$this->version;
	echo '<link rel="stylesheet" type="text/css" href="' . $path . '" />';
	echo "\n";
	$path = WEBLIB_JSURL . '/admin.js?version='.$this->version;
	echo '<script type="text/javascript" src="' . $path . '"></script>';
	echo "\n";
	echo '<script> var WEBLIB_BASEURL = "'.WEBLIB_BASEURL.'";</script>';
	echo "\n";
    }
    function widgets_init() {
	register_widget('WEBLIB_StrippedMeta');
    }
    function body_class($classes='') {
	$classes[] = "no-js";
	return $classes;
    }
    function every_day() {
	$cleared = HoldItem::ClearExpiredHolds();
    }
    function admin_menu() {
	$this->admin_page = new WEBLIB_AdminPages();
	if (current_user_can('manage_circulation')) {
	   add_action('wp_dashboard_setup',array($this->admin_page,
						 'wp_dashboard_setup'));
	}
	add_action('wp_dashboard_setup',array($this->admin_page,
						'user_wp_dashboard_setup'));
    }
}

/* Define widget code */
class WEBLIB_StrippedMeta extends WP_Widget {
    function __construct() {
	$widget_ops = array('classname' => 'widget_strippedmeta', 'description' => __( "Log in/out, admin") );
	$this->WP_Widget('strippedmeta', __('Stripped Meta'), $widget_ops);
    }

    function widget( $args, $instance ) {
	extract($args);
	echo $before_widget;
?>
	    <ul>
	    <?php
		if (is_user_logged_in()){ ?>
		    <li><a href="<?php echo bloginfo('wpurl');
		    ?>/wp-admin" alt="admin">Dashboard</a></li><?php
		} else { ?>
		    <li><a href="<?php
		    echo site_url('wp-login.php?action=register', 'login');
		    ?>">Register</a></li><?php
		} ?>
	    <li><?php wp_loginout(); ?></li>
	    </ul>
<?php
	echo $after_widget;
    }

    function update( $new_instance, $old_instance ) {
	$instance = $old_instance;
	return $instance;
    }

    function form( $instance ) {
	$instance = wp_parse_args( (array) $instance, array( 'title' => '' ) );
    }
}

/* Create an instanance of the plugin */
global $weblibrarian;
$weblibrarian = new WebLibrarian();

